function [ Global ] = CONSTANTS(Global)

% Constants to use in Thermodynamic Analysis Tool (TDAT)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Gas constant from the NASA GLENN DATABASE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Global.R0 = 8.31451; % [J mol-1 K-1]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Molar weights for O2, N2, CO, H2, CO2, H2O from the NASA GLENN DATABASE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Global.MO2 =  31.9988000;   % Molar weight O2 [g/mol]
Global.MN2 =  28.0134000;   % Molar weight N2 [g/mol]
Global.MCO =  28.0101000;   % Molar weight CO [g/mol]
Global.MH2 =   2.0158800;   % Molar weight H2 [g/mol]
Global.MCO2 = 44.0095000;   % Molar weight CO2 [g/mol]
Global.MH2O = 18.0152800;   % Molar weight H2O [g/mol]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Gas constants for O2, N2, CO, H2, CO2, H2O from the NASA GLENN DATABASE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Global.RCO = Global.R0/Global.MCO*1e3;      % Gas constant CO [J/kgK]
Global.RCO2 = Global.R0/Global.MCO2*1e3;    % Gas constant CO2 [J/kgK]
Global.RH2 = Global.R0/Global.MH2*1e3;      % Gas constant H2 [J/kgK]
Global.RO2 = Global.R0/Global.MO2*1e3;      % Gas constant O2 [J/kgK]
Global.RH2O = Global.R0/Global.MH2O*1e3;    % Gas constant H2O [J/kgK]
Global.RN2 = Global.R0/Global.MN2*1e3;      % Gas constant N2 [J/kgK]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Volume of combustion rig
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Radius of rig
Global.r = 0.125;   % [m]
% Hight of rig
Global.h = 0.1;     %  [m]

% Area of the combustion rig
Global.A = 2*pi*Global.r^2 + pi*2*Global.r*Global.h; % [m^2]
% Volume of combustion rig
Global.V = pi * Global.r^2 * Global.h; %[m^3]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial conditions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Setting parameters for importing data from the excel-spreadsheets

file = Global.file_name;
input = 'Data_Input';

% Time releative to ignition pulse start
Global.time = xlsread(file,input,'A6:A50005'); % [s]

% Time between spark ignition and diesel injection
Global.injection_time = xlsread(file,input,'F2')/1e6; % [s]

% Temperature in combustion rig wall
Global.Tw = xlsread(file,input,'G6') + 273.15; % [K]

% Temperature in 1mm sensor converted to [K]
Global.T0 = xlsread(file,input,'C6') + 273.15;
% Static and gas charge pressure
Global.p0= xlsread(file,input,'H6')*1e5; % [Pa]

% Air pressure set to 1 [bar]
Global.pair = 1*1e5; % [Pa]

% Static pressure sensor
p_stat = (xlsread(file,input,'H6:H50005').*1e5)'; % [Pa]

% Temperature in 1mm sensor
Global.T1mm = xlsread(file,input,'C6:C50005')+ 273.15; % [K]

% Temperature in 3mm sensor
Global.T3mm = xlsread(file,input,'B6:B50005') + 273.15; % [K]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dynamic pressure implementation and numeric differation                
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Dynamic pressure sensor 1
pdyn1 = xlsread(file,input,'K6:K50005')*1e5; % [Pa]
% Dynamic pressure sensor 2
pdyn2 = xlsread(file,input,'M6:M50005')*1e5; % [Pa]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Numerical differation from measured values of pdyn with uncertinites
% Method from O. Amble; "Numeriske metoder II", lectures fall 1966 and
% spring 1967
% dy = 1/h [2/3*(y_{i+1}-y_{i-1}) - 1/12(y_{i+2}-y_{i-2})] with h = x_{i+1}
%-x_{i} = constant. Here it is the time between measurements
% This method also partly smoothens the measurements
% Differential from i=1 to 2 is lost, but assume p(2) = p(1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Inital difference between dynamic pressure sensor 1 and static pressure
% sensor
pdiff1 = Global.p0-pdyn1(1); % [Pa]
% Inital difference between dynamic pressure sensor 2 and static pressure
% sensor
pdiff2 = Global.p0-pdyn2(1); % [Pa]

% Initiating matrixes to increase calculation speed
p1 = zeros(1,length(pdyn1));
p2 = zeros(1,length(pdyn2));

for m=1:length(pdyn1)
p1(m) = pdyn1(m) + pdiff1 + 1e5;
p2(m) = pdyn2(m) + pdiff2 + 1e5;
end

Global.p = p1;                  % [Pa]
Global.p_stat = p_stat+1e5;     % [Pa]
Global.p1 = p1;                 % [Pa]
Global.p2 = p2;                 % [Pa]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TIME FOR SIMULATION OF COOL DOWN PHASE FOR HEAT LOSS SIMULATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Set the timespan for the calculations
 [~, idx] = max(p1); 
% Add 250*0.002 = 0.05 [s] to finish the pre-combustion 
 Global.combustion_end = idx + 250;
% Find the index for the injection start
 Global.injection_start = find(Global.time==Global.injection_time);
 
 % Finding the max value after injection
[~, id_max] = max(Global.p(Global.injection_start:end));

 % Set finishing time for calculating ROHR from the injection experiment
Global.injection_end = id_max*2 + Global.injection_start;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Gas composition
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Gas constant gas mixture
Global.Rgas = Global.RCO * Global.xCOgas + Global.RN2 * Global.xN2gas ...
    + Global.RO2 * Global.xO2gas; % [J/kgK]

% Molar mass of gas mixture
Global.Mgas = Global.R0/Global.Rgas*1e3; % [g/mol]

% Calculates volumfractions based on y_i = x_i * R0 / (M_i + sum[R_i*x_i])
Global.yCOgas = (Global.xCOgas * Global.R0)/(Global.MCO*...
    (Global.RCO*Global.xCOgas + Global.RN2*Global.xN2gas + ...
    Global.RO2*Global.xO2gas + Global.RH2*Global.xH2gas))*1e3;
Global.yH2gas = (Global.xH2gas * Global.R0)/(Global.MH2*...
    (Global.RCO*Global.xCOgas + Global.RN2*Global.xN2gas + ...
    Global.RO2*Global.xO2gas + Global.RH2*Global.xH2gas))*1e3;
Global.yO2gas = (Global.xO2gas * Global.R0)/(Global.MO2*...
    (Global.RCO*Global.xCOgas + Global.RN2*Global.xN2gas...
    + Global.RO2*Global.xO2gas + Global.RH2*Global.xH2gas))*1e3; 
Global.yN2gas = (Global.xN2gas * Global.R0)/(Global.MN2*...
    (Global.RCO*Global.xCOgas + Global.RN2*Global.xN2gas...
    + Global.RO2*Global.xO2gas + Global.RH2*Global.xH2gas))*1e3;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Air composition and properties
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Mass fraction O2 [-]
Global.xO2air = Global.yO2air*Global.MO2/... 
    (Global.yO2air*Global.MO2 + Global.yN2air*Global.MN2); 
% Mass fraction N2 [-]
Global.xN2air = Global.yN2air*Global.MN2/... 
    (Global.yO2air*Global.MO2 + Global.yN2air*Global.MN2);

% Gas constant air
Global.Rair = Global.RO2 * Global.xO2air ...
    + Global.RN2 * Global.xN2air; % [J/kgK]

% Molar mass air
Global.Mair = Global.R0/Global.Rair*1e3; % [g/mol]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Masses in rig
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Mass of each gas in air and mixture
Global.mO2air = Global.V/Global.T0 * ((Global.pair*Global.xO2air)/...
    Global.Rair); % [kg]
Global.mN2air = Global.V/Global.T0 * ((Global.pair*Global.xN2air)/...
    Global.Rair); % [kg]
Global.mO2gas = Global.V/Global.T0 * ((Global.p0*Global.xO2gas)/...
    Global.Rgas); % [kg]
Global.mN2gas = Global.V/Global.T0 * ((Global.p0*Global.xN2gas)/...
    Global.Rgas); % [kg]
Global.mCOgas = Global.V/Global.T0 * ((Global.p0*Global.xCOgas)/...
    Global.Rgas); % [kg]
Global.mH2gas = Global.V/Global.T0 * ((Global.p0*Global.xH2gas)/...
    Global.Rgas); % [kg]

% Mass of air and gas in rig
Global.mair = Global.mO2air + Global.mN2air; % [kg]
Global.mgas = Global.mO2gas + Global.mN2gas + Global.mCOgas; % [kg]

% Masses each component in gas mixture
Global.mO2mix = Global.mO2air + Global.mO2gas; % [kg]
Global.mN2mix = Global.mN2air + Global.mN2gas; % [kg]
Global.mCOmix = Global.mCOgas; % [kg]
Global.mH2mix = Global.mH2gas; % [kg]

% Mass fractions gas mix
Global.xO2mix = Global.mO2mix / (Global.mO2mix + Global.mN2mix ...
    + Global.mCOmix + Global.mH2mix);
Global.xN2mix = Global.mN2mix / (Global.mO2mix + Global.mN2mix ...
    + Global.mCOmix + Global.mH2mix);
Global.xCOmix = Global.mCOmix / (Global.mO2mix + Global.mN2mix ...
    + Global.mCOmix + Global.mH2mix);
Global.xH2mix = Global.mH2mix / (Global.mO2mix + Global.mN2mix + ...
    Global.mCOmix + Global.mH2mix);

% Gas constant gas mix
Global.Rmix = Global.RCO*Global.xCOmix + ...
    Global.RN2*Global.xN2mix + Global.RO2*Global.xO2mix ...
    + Global.RH2*Global.xH2mix; % [J/kgK]

% Molar mass gas mix
Global.Mmix = Global.R0/Global.Rmix*1e3; % [kg/kmol]

% Total mass in rig summing mass of air and mass of gas
Global.mrig = Global.mair + Global.mgas; % [kg]
% Total mass in rig for control summing each gas in the air and in the rig
Global.mrig_control = Global.mO2air + Global.mN2air + Global.mCOgas ...
    + Global.mN2gas + Global.mO2gas + Global.mH2gas; % [kg]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Constants initiatet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Variable to count number of runtroughs
Global.s = 1;

% Initial set combustion efficinecy
Global.eta_comb(1) = 0.95;

% Initial temperature difference between temperature calculated from the 
% combustion efficency and the Two-zone model solving
Global.T_diff(1) = 0;

% Inital value for gain in PI-control of k in Eichelbergs heat coefficient
% formula
Global.v(1) = 0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ROHR for pre-combustion phase
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Lower heating value CO from Heywood Ch. 3.5.2
Global.hn_CO = 10.1032*1e6; % [J/kg]

% Lower heating value H2 from Heywood Ch. 3.5.2
Global.hn_H2 = 119.961*1e6; % [J/kg]

% For the two zone model total mass transport dm = dm12
% ROHR = dQ/dt = h_n*dm_f = hn_CO*dm_CO + hn_H2*dmH2
% ROHR = (hn_CO*xCOmix + hn_H2*xH2mix)*dm12

% Lower heating value for mixture of H2 and CO, 
% to be multiplied with total mass, m12
Global.hn = Global.hn_CO*Global.xCOmix...
    + Global.hn_H2*Global.xH2mix; % [J/kg]

% Fuel energy in CO
Global.Q_CO = Global.hn_CO*Global.mCOmix; % [J]

% Fuel energy in H2
Global.Q_H2 = Global.hn_H2*Global.mH2mix; % [J]
% Total fuel energy in the charged bomb
Global.Q_tot = Global.Q_CO + Global.Q_H2; % [J]