function [ h, temp ] = ENTALPHY(T2, Global)
%ENTALPHY Calculates the entalphy for the mixed gases in the combustion rig
%   This function generates the entalphy from NASA GLENN DATABASE 
%   for the mixed gases from zone 1 and zone 2 after pre-combustion 
%   is completed.

% Set temperature span for the calculations
T = round(T2);
% Temperatures 100 K above and 100 K below the final temperature in zone 2
temp = T-200:0.001:T+200;

% Set matrixes for increased calculation speed
h_CO = zeros(1,length(temp));
h_CO2 = zeros(1,length(temp));
h_H2 = zeros(1,length(temp));
h_N2 = zeros(1,length(temp));
h_O2 = zeros(1,length(temp));
h_H2O = zeros(1,length(temp));

% Defines the gas constants for use in this function
RCO = Global.RCO/1000; % [kJ/kgK]
RCO2 = Global.RCO2/1000; % [kJ/kgK]
RH2 = Global.RH2/1000; % [kJ/kgK]
RN2 = Global.RN2/1000; % [kJ/kgK]
RO2 = Global.RO2/1000; % [kJ/kgK]
RH2O = Global.RH2O/1000; % [kJ/kgK]

% Calculates Cp^0(T)/R and H^0(T)/RT using NASA GLENN DATABASE polynom

for i = 1:length(temp)
    
    % Load coefficents from COEFFICIENTS function
    [CO, CO2, H2, N2, O2, H2O] = COEFFICIENTS(temp(i));
    
    % Calculates h(T) [J/kg] with h(T) = [H^0(T)/RT]*RT for each gas
    h_CO(i) = (-CO(1)*(temp(i)^-2) + CO(2)*(log(temp(i))/temp(i)) ...
        + CO(3) + CO(4)*temp(i)/2 + CO(5)*(temp(i)^2)/3 ...
        + CO(6)*(temp(i)^3)/4 + CO(7)*(temp(i)^4)/5 ...
        + CO(8)/temp(i)) * RCO*temp(i);

    h_CO2(i) = (-CO2(1)*temp(i)^-2 + CO2(2)*(log(temp(i))/temp(i)) + ...
        CO2(3) + CO2(4)*temp(i)/2 + CO2(5)*((temp(i)^2)/3) + ...
        CO2(6)*((temp(i)^3)/4) + CO2(7)*((temp(i)^4)/5) + ...
        CO2(8)/temp(i)) * RCO2*temp(i);
   
    h_H2(i) = (-H2(1)*temp(i)^-2 + H2(2)*(log(temp(i))/temp(i)) + ...
        H2(3) + H2(4)*temp(i)/2 + H2(5)*((temp(i)^2)/3) + ...
        H2(6)*((temp(i)^3)/4) + H2(7)*((temp(i)^4)/5) + ...
        H2(8)/temp(i)) * RH2*temp(i);
    
    h_N2(i) = (-N2(1)*temp(i)^-2 + N2(2)*(log(temp(i))/temp(i)) + ...
        N2(3) + N2(4)*temp(i)/2 + N2(5)*((temp(i)^2)/3) + ...
        N2(6)*((temp(i)^3)/4) + N2(7)*((temp(i)^4)/5) + ...
        N2(8)/temp(i)) * RN2*temp(i);
    
    h_O2(i) = (-O2(1)*temp(i)^-2 + O2(2)*(log(temp(i))/temp(i)) + ...
        O2(3) + O2(4)*temp(i)/2 + O2(5)*((temp(i)^2)/3) + ...
        O2(6)*((temp(i)^3)/4) + O2(7)*((temp(i)^4)/5) + ...
        O2(8)/temp(i)) * RO2*temp(i);
    
    h_H2O(i) = (-H2O(1)*temp(i)^-2 + H2O(2)*(log(temp(i))/temp(i)) + ...
        H2O(3) + H2O(4)*temp(i)/2 + H2O(5)*((temp(i)^2)/3) + ...
        H2O(6)*((temp(i)^3)/4) + H2O(7)*((temp(i)^4)/5) + ...
        H2O(8)/temp(i)) * RH2O*temp(i);

end

% Calculates the resulting entalphy for the CR
h = h_CO.*Global.xCOp + h_CO2.*Global.xCO2p + h_H2.*Global.xH2p ...
    + h_N2.*Global.xH2p + h_O2.*Global.xO2p + h_H2O.*Global.xH2Op;

end

