function [ Cv, kappa ] = HEAT_CAPACITY( Global, T)
%HEAT_CAPACITY Calculate cv and kappa
% Uses the NASA GLENN DATABSE to calculate Cv and kappa for the gas after
% the pre-combustion based on the chemical equation

% Defines the gas constants for use in this function
RCO = Global.RCO/1000; % [kJ/kgK]
RCO2 = Global.RCO2/1000; % [kJ/kgK]
RH2 = Global.RH2/1000; % [kJ/kgK]
RN2 = Global.RN2/1000; % [kJ/kgK]
RO2 = Global.RO2/1000; % [kJ/kgK]
RH2O = Global.RH2O/1000; % [kJ/kgK]

% Calculates Cp^0(T)/R and H^0(T)/RT using NASA GLENN DATABASE polynom
    
    [CO, CO2, H2, N2, O2, H2O] = COEFFICIENTS(T);
    
    CpR_CO = (CO(1)*T^-2 + CO(2)*T^-1 + ...
        CO(3) + CO(4)*T + CO(5)*T^2 + ...
        CO(6)*T^3 + CO(7)*T^4);
    
    CpR_CO2 = (CO2(1)*T^-2 + CO2(2)*T^-1 + ...
        CO2(3) + CO2(4)*T + CO2(5)*T^2 + ...
        CO2(6)*T^3 + CO2(7)*T^4);
    
    CpR_H2 = (H2(1)*T^-2 + H2(2)*T^-1 + ...
        H2(3) + H2(4)*T + H2(5)*T^2 + ...
        H2(6)*T^3 + H2(7)*T^4);
    
    CpR_N2 = (N2(1) * T^-2 + N2(2) * T^-1 + ...
        N2(3) + N2(4)*T + N2(5)*T^2 + ...
        N2(6)*T^3 + N2(7)*T^4);
    
    CpR_O2 = (O2(1) * T^-2 + O2(2) * T^-1 + ...
        O2(3) + O2(4)*T + O2(5)*T^2 + ...
        O2(6)*T^3 + O2(7)*T^4);
    
    CpR_H2O = (H2O(1)*T^-2 + H2O(2)*T^-1 + ...
        H2O(3) + H2O(4)*T + H2O(5)*T^2 + ...
        H2O(6)*T^3 + H2O(7)*T^4);

% Calculates Cp(T) [J/kgK] with Cp(T) = [Cp^0(T)/R]*R for each gas
    Cp_CO = CpR_CO * RCO;
    Cp_CO2 = CpR_CO2 * RCO2;
    Cp_H2 = CpR_H2 * RH2;
    Cp_N2 = CpR_N2 * RN2;
    Cp_O2 = CpR_O2 * RO2;
    Cp_H2O = CpR_H2O * RH2O;

% Calculates Cv(T) [J/kgK] with Cv(T) = Cp(T) - R for each gas
    Cv_CO = Cp_CO - RCO;
    Cv_CO2 = Cp_CO2 - RCO2;
    Cv_H2 = Cp_H2 - RH2;
    Cv_N2 = Cp_N2 - RN2;
    Cv_O2 = Cp_O2 - RO2;
    Cv_H2O = Cp_H2O - RH2O;
    
    Cv = Cv_CO*Global.xCOp + Cv_CO2*Global.xCO2p ...
        + Cv_H2*Global.xH2p + Cv_N2*Global.xN2p ...
        + Cv_O2*Global.xO2p + Cv_H2O*Global.xH2Op;
    
    % Calculates kappa [-] with kappa = Cp/Cv for each gas
    kappa_CO = Cp_CO/Cv_CO;
    kappa_CO2 = Cp_CO2/Cv_CO2;
    kappa_H2 = Cp_H2/Cv_H2;
    kappa_N2 = Cp_N2/Cv_N2;
    kappa_O2 = Cp_O2/Cv_O2;
    kappa_H2O = Cp_H2O/Cv_H2O;
    
    kappa = kappa_CO*Global.xCOp + kappa_CO2*Global.xCO2p ...
        + kappa_H2*Global.xH2p + kappa_N2*Global.xN2p ...
        + kappa_O2*Global.xO2p + kappa_H2O*Global.xH2Op;
    
    
    