function [ Global ] = HEAT_LOSS_COEFFICIENT( Global )
%HEAT_LOSS_COEFFICIENT Calculates the heat loss coefficient
%   This function calculates a first approximation of the heat loss in the
%   CR based on Eichelbergs formula alpha=2.47(p*T)^0.5 and using the gas
%   compostion based on a fixed combustion efficency

% Area of wall in rig
A  = Global.A; % [m^2]
% Volume of the CR
V = Global.V; % [m^3]
% Gas constant of burned gas
R = Global.Rburned; % [J/kgK]
% Total mass in rig
m = Global.mrig; % [kg]
% Temperature of combustion rig
T_w = Global.Tw; % [K]
% Pressure in the cool down phase
p = Global.p(Global.combustion_end:Global.injection_start); % [Pa]
% Time span for the cool down phase
cool_down_time = ...
    Global.time(Global.combustion_end:Global.injection_start); % [s]
% Counting variable
s = Global.s; % [-]
% Temperature difference between T12 and T(1) in cool down phase
T_diff = Global.T_diff; % [K]
% Volume of the CR
v = Global.v; % [m^3]

% Calculates the temperature in the zone assuming prefect mixed gas and
% ideal gas properties
% pV = mRT

% Creating initial matrixes to increase calculation speed
alpha_N = zeros(length(R),length(p));
dQ_N = zeros(length(R),length(p));
Cv = zeros(length(R),length(p));
kappa = zeros(length(R),length(p));

% Temperature calculated using the ideal gas law
temp = ((V.*p)/(m*R)); % [K]

% Time step
h = cool_down_time(2)-cool_down_time(1); % [s]

% Finding curve fit
f2 = fit(cool_down_time,p','exp2');

% Coefficents from the fit to the cool down curve with
% f2(x) = a*exp(b*x) + c*exp(d*x)

a2 = f2.a;
b2 = f2.b;
c2 = f2.c;
d2 = f2.d;

% Calculate the pressure fit for the cool down phase
dp_exp2 = a2*b2*exp(b2.*cool_down_time) + c2*d2*exp(d2.*cool_down_time);

% Using Newtons law of Convection to determine the heat loss
% dQdt = alpha * A * (T_gas-T_wall) = m * c_v * dTdt
for i = 1:length(R)
    for j = 1:length(p)
        
        % Calculating the total heat capacity and kappa at the specified
        % temperature
        [ Cv(j), kappa(j) ] = HEAT_CAPACITY( Global, temp(i,j));
        
        % Ideal gas: R = c_p - c_v, c_p/c_v = kappa and dTdt = dpdt*V/(m*R)
        dQ_N(j) = 1/(kappa(j)-1)*V*dp_exp2(j);
        
        % Solving for alpha
        alpha_N(j) = dQ_N(j)/(A * (temp(i,j) - T_w));

    end
end

% Fit the Eichelberg formula alpha = k * sqrt(p*T) to the alpha calculated
% by Newtons formula

% Guess of Eichelberg factor
x0  = -0.003;
xdata = cool_down_time;
ydata = alpha_N;

% Create the anonmous function to calculate alpha with Eichelbergs formula
fun = @(x,xdata)(x.*sqrt(p.*temp));

% Turn off the option of printing the resulting fitting value
options = optimoptions(@lsqcurvefit,'Display','off');
lb = [];
ub = [];

% Coefficient to fit Eichelbergs formula against Newtons law of cooling
epsilon = lsqcurvefit(fun,x0,xdata,ydata,lb,ub,options);

% PI-controller for tuning Eichelbergs constant with difference in 
% temperature in start of cool down phase based on temperatures calculated 
% the two-zone model and from the comopstion after chemical reaction

T = 1; % Universal sampling time
T_i = 1; % Integration constant
Kp = 2.5e-6; % Proportional gain
e = T_diff; % Error between set and measured value

% Calculate the controller output to correct epsilon
if s>1
    for z = s:s
    v(z) =  v(z-1) + Kp*((1+T/(2*T_i))*e(z) - (1-T/(2*T_i))*e(z-1));
    end
end

% Store epsilon to calculate the heat loss from zone 2 when solving the
% two-zone model
Global.epsilon = epsilon - v(s);


% Global.T_comb_end = temp(1);


% Global.cooldown_time = cool_down_time;

% Calculated values to be displayed in GUI
Global.p_injection = p(end);
Global.T_injection = temp(end);
Global.T_cooldown = temp(1);

% Set the correction from the controller to store in the Global struct to
% be able to check it for later runs 
Global.v = v;

end


