function [ kappa ] = KAPPA( Global, temp)
%Termo_properties Calculates the termodynamic properties of the combustion
%gases
%   Uses the NASA GLENN DATABASE to do the calculations for finding Cp, Cv,
%   and kappa = Cp/Cv for CO, CO2, H2, N2, O2, H2O

% Set matrixes for increased calculation speed
CpR_CO = zeros(1,length(temp));
CpR_CO2 = zeros(1,length(temp));
CpR_H2 = zeros(1,length(temp));
CpR_N2 = zeros(1,length(temp));
CpR_O2 = zeros(1,length(temp));
CpR_H2O = zeros(1,length(temp));

% Defines the gas constants for use in this function
RCO = Global.RCO/1000; % [kJ/kgK]
RCO2 = Global.RCO2/1000; % [kJ/kgK]
RH2 = Global.RH2/1000; % [kJ/kgK]
RN2 = Global.RN2/1000; % [kJ/kgK]
RO2 = Global.RO2/1000; % [kJ/kgK]
RH2O = Global.RH2O/1000; % [kJ/kgK]

% Calculates Cp^0(T)/R and H^0(T)/RT using NASA GLENN DATABASE polynom

for i = 1:length(temp)
    
    [CO, CO2, H2, N2, O2, H2O] = COEFFICIENTS(temp(i));
    
    CpR_CO(i) = (CO(1)*temp(i)^-2 + CO(2)*temp(i)^-1 + ...
        CO(3) + CO(4)*temp(i) + CO(5)*temp(i)^2 + ...
        CO(6)*temp(i)^3 + CO(7)*temp(i)^4);
    
    CpR_CO2(i) = (CO2(1)*temp(i)^-2 + CO2(2)*temp(i)^-1 + ...
        CO2(3) + CO2(4)*temp(i) + CO2(5)*temp(i)^2 + ...
        CO2(6)*temp(i)^3 + CO2(7)*temp(i)^4);
    
    CpR_H2(i) = (H2(1)*temp(i)^-2 + H2(2)*temp(i)^-1 + ...
        H2(3) + H2(4)*temp(i) + H2(5)*temp(i)^2 + ...
        H2(6)*temp(i)^3 + H2(7)*temp(i)^4);
    
    CpR_N2(i) = (N2(1) * temp(i)^-2 + N2(2) * temp(i)^-1 + ...
        N2(3) + N2(4)*temp(i) + N2(5)*temp(i)^2 + ...
        N2(6)*temp(i)^3 + N2(7)*temp(i)^4);
    
    CpR_O2(i) = (O2(1) * temp(i)^-2 + O2(2) * temp(i)^-1 + ...
        O2(3) + O2(4)*temp(i) + O2(5)*temp(i)^2 + ...
        O2(6)*temp(i)^3 + O2(7)*temp(i)^4);
    
    CpR_H2O(i) = (H2O(1)*temp(i)^-2 + H2O(2)*temp(i)^-1 + ...
        H2O(3) + H2O(4)*temp(i) + H2O(5)*temp(i)^2 + ...
        H2O(6)*temp(i)^3 + H2O(7)*temp(i)^4);

end

% Calculates Cp(T) [J/kgK] with Cp(T) = [Cp^0(T)/R]*R for each gas
    Cp.CO = CpR_CO .* RCO;
    Cp.CO2 = CpR_CO2 .* RCO2;
    Cp.H2 = CpR_H2 .* RH2;
    Cp.N2 = CpR_N2 .* RN2;
    Cp.O2 = CpR_O2 .* RO2;
    Cp.H2O = CpR_H2O .* RH2O;

% Calculates Cv(T) [J/kgK] with Cv(T) = Cp(T) - R for each gas
    Cv.CO = Cp.CO - RCO;
    Cv.CO2 = Cp.CO2 - RCO2;
    Cv.H2 = Cp.H2 - RH2;
    Cv.N2 = Cp.N2 - RN2;
    Cv.O2 = Cp.O2 - RO2;
    Cv.H2O = Cp.H2O - RH2O;

% Calculates kappa [-] with kappa = Cp/Cv for each gas
    kappa_CO = Cp.CO./Cv.CO;
    kappa_CO2 = Cp.CO2./Cv.CO2;
    kappa_H2 = Cp.H2./Cv.H2;
    kappa_N2 = Cp.N2./Cv.N2;
    kappa_O2 = Cp.O2./Cv.O2;
    kappa_H2O = Cp.H2O./Cv.H2O;
    
% Calculates kappa for the total mixture

kappa = kappa_CO*Global.xCOp + kappa_CO2*Global.xCO2p ...
    + kappa_H2*Global.xH2p + kappa_N2*Global.xN2p ...
    + kappa_O2*Global.xO2p + kappa_H2O*Global.xH2Op;
end
