function dx = ODEFUN( t, x, Global, p, dp, initial_part_zone2)
%ODEFUN Calculate and update the state matrix for the two-zone model
%   This function take the solved states from ode15s to update the A matrix
%   used to calculate dotx = A^-1 * x

% Time in calculation
time = Global.time; % [s]
% Volume of rig
V = Global.V;  % [m^3]
% Area of rig
A = Global.A; %  [m^2]
% Rig wall temperature
Tw = Global.Tw;  % [K]
% Mass in rig 
mrig = Global.mrig; % [kg]
% Time step between measurements
h = time(2)-time(1); % [s]
% Coefficient in Eichelbergs formula
epsilon = Global.epsilon; 


% Find the pressure corresponding to the simulation time
i = find((time-t)<=h,1,'first');
psolver = p(i); % [Pa]
dpsolver = dp(i); % [Pa]

% Initial mass in zone two, must be unequal to zero
m2_0 = mrig*initial_part_zone2; % [kg]
% Inital mass in rig, all in zone one
m1_0 = mrig - m2_0; % [kg]
% Initial volume zone 2
V2_0 = V*initial_part_zone2; % [m^3]

% Mass in zone decrease with m12
m1 = m1_0 - x(1); % [kg]
% Mass in zone increase with m12
m2 = m2_0 + x(1); % [kg]
% Temperature in zone 1
T1 = x(2); % |K]
% Volume in zone 1
V1 = x(3); % [m^3]
% Temperature in zone 2
T2 = x(4); % [K]
% Volme in zone 2 V = V1+V2
V2 = V2_0 + V-V1; % [m^3]


% Calculation of composition in zone 1 and zone 2
[ zone1, zone2 ] = ZONES_DATA( Global );

% Check if the temperature in zone 1 is above required 200 K, which can
% occur in the initiating phase of the differential solution
if T1>=200
    % Calculate the thermodynamic properties in zone 1
    [ ~, Cv, ~, h, u ] = ZONES_THERMO_PROPERTIES( T1, Global, zone1 );
    h1 = h.zone;  % [J/kg] 
    u1 = u.zone;  % [J/kg]
    Cv1 = Cv.zone;  % [J/kgK]
else
    % If the temperature is to low, set to the minimum value to continue
    % calculations
    T1 = 200;
    % Calculate the thermodynamic properties in zone 1
    [ ~, Cv, ~, h, u ] = ZONES_THERMO_PROPERTIES( T1, Global, zone1 );
    h1 = h.zone;  % [J/kg] 
    u1 = u.zone;  % [J/kg]
    Cv1 = Cv.zone;  % [J/kgK]
end

% Check if the temperature in zone 2 is above required 200 K, which can
% occur in the initiating phase of the differential solution
if T2>=200
    % Calculate the thermodynamic properties in zone 2
    [ ~, Cv, ~, ~, u ] = ZONES_THERMO_PROPERTIES( T2, Global, zone2 );
    u2 = u.zone;  % [J/kg]
    Cv2 = Cv.zone;  % [J/kgK]
else
    % If the temperature is to low, set to the minimum value to continue
    % calculations
    T2 = 200;
    % Calculate the thermodynamic properties in zone 2
    [ ~, Cv, ~, ~, u ] = ZONES_THERMO_PROPERTIES( T2, Global, zone2 );
    u2 = u.zone;  % [J/kg]
    Cv2 = Cv.zone;  % [J/kgK]
end

% Heat losses in zone 1 and zone 2 wiht dotQ = alpha * A * (T-Tw)

% Heat loss from zone 1
alpha_1 = epsilon * sqrt(psolver*T1);
% dQ1 = 0 because the gas composition used to calculate epsilon is assumed
% to be more similiar to zone 2
dQ1 =  0; %alpha_1 * A * (T1-Tw) * V1/V;

% Heat loss from zone 2
alpha_2 = epsilon * sqrt(psolver*T2);
dQ2 =  alpha_2 * A * (T2-Tw);

% Matrixes for solving the two zone model A*dx/dt = b
A = [1/m1, 1/T1, 1/V1, 0; ...
    (h1-u1), m1*Cv1, psolver, 0; ...
    1/m2, 0 , 1/V2, 1/T2;...
    (h1-u2), 0, psolver, -m2*Cv2];

b = [-dpsolver/psolver; dQ1 ; dpsolver/psolver; -dQ2 ];

% Return changes in the states
dx = A\b;

end

