function [ Global ] = ROHR( Global )
%ROHR Calculates rate of heat release (ROHR) 
%   ROHR is first calculated for the pre-combustion, then ROHR from the
%   injection experiment is calculated

% Setting time span for the two-zone combustion
time_tz = Global.time_two_zones; % [s]
% Mass transport from zone 1 to zone 2
m12 = Global.m12; % [kg]
% Lower heating value for mixture of CO an H2
hn = Global.hn; % [J/kg]
% Pressure in injection phase
p = Global.p(Global.injection_start:Global.injection_end); % [Pa]
% Setting timespan for injection experiment
time = Global.time(Global.injection_start:Global.injection_end); % [s]
% Temperature at injection start
T_injection = Global.T_injection; % [K]
% Volume of the combustion rig
V = Global.V; % [m^3]

% Rate of heat release for the pre-combustion phase 

% Fit the mass function with a fourier fit function
m12_fit = fit(time_tz,m12,'fourier8');

% Collect the parameters from the fit
m_a1 = m12_fit.a1;
m_a2 = m12_fit.a2;
m_a3 = m12_fit.a3;
m_a4 = m12_fit.a4;
m_a5 = m12_fit.a5;
m_a6 = m12_fit.a6;
m_a7 = m12_fit.a7;
m_a8 = m12_fit.a8;
m_b1 = m12_fit.b1;
m_b2 = m12_fit.b2;
m_b3 = m12_fit.b3;
m_b4 = m12_fit.b4;
m_b5 = m12_fit.b5;
m_b6 = m12_fit.b6;
m_b7 = m12_fit.b7;
m_b8 = m12_fit.b8;
m_w = m12_fit.w;

% Calculate the rate of mass change form zone 1 to zone 2 with the fitted
% funtion to get a smoot curve
dm12_fit = m_w*(-m_a1*sin(m_w.*time_tz) - 2*m_a2*sin(2*m_w.*time_tz) ...
    - 3*m_a3*sin(3*m_w.*time_tz) - 4*m_a4*sin(4*m_w.*time_tz) ...
    - 5*m_a5*sin(5*m_w.*time_tz) - 6*m_a6*sin(6*m_w.*time_tz) ...
    - 7*m_a7*sin(7*m_w.*time_tz) - 8*m_a8*sin(8*m_w.*time_tz) ...
    + m_b1*cos(m_w.*time_tz) + 2*m_b2*cos(2*m_w.*time_tz) ...
    + 3*m_b3*cos(3*m_w.*time_tz) + 4*m_b4*cos(4*m_w.*time_tz) ...
    + 5*m_b5*cos(5*m_w.*time_tz) + 6*m_b6*cos(6*m_w.*time_tz)...
    + 7*m_b7*cos(7*m_w.*time_tz) + 8*m_b8*cos(8*m_w.*time_tz));

% Numerical differentiation of the mass curve
dm12 = zeros(1,length(m12));

 for i = 3:(length(m12)-2)
     
     y = time_tz(i+1)-time_tz(i);
     
    dm12(i) = 1/y * (2/3*(m12(i+1)-m12(i-1)) ...
        - 1/12*(m12(i+2)-m12(i-2)));
 end
 
 % Assume liniarity in the three first and three last points
 dm12(1) = dm12(3);
 dm12(2) = dm12(3);
 dm12(end) = dm12(end-2);
 dm12(end-1) = dm12(end-2);
 
% Calculate the ROHR for the pre-combustion phase both numerical
% and fitted with furier 8
ROHR_pre_combustion_numeric = hn .* dm12;
ROHR_pre_combustion = hn .* dm12_fit;

% Calculates the total heat release in the pre-combustion phase
Q_pre_fit = trapz(time_tz,ROHR_pre_combustion);

% Rate of heat release for the injection experiment, closed system analysis
% Set injection start to start of calculation
time_injection = time - Global.time(Global.injection_start);

% Create array to increase numerical differential calculation
dp_injection = zeros(1,length(p));

% Time between measurements
h = time(2)-time(1);

 for j = 3:(length(p)-2)
 
    dp_injection(j) = 1/h * (2/3*(p(j+1)-p(j-1)) ...
        - 1/12*(p(j+2)-p(j-2)));
    
 end
 
 % Assume liniarity in the three first and three last points
 dp_injection(1) = dp_injection(3);
 dp_injection(2) = dp_injection(3);
 dp_injection(end) = dp_injection(end-2);
 dp_injection(end-1) = dp_injection(end-2);
 
 % Find a smooth pressure differential curve
 dp_smooth = smooth(dp_injection');
 
 % Calculate kappa for the injection experiment
 [ kappa ] = KAPPA( Global, T_injection);
 
 % Set arrays to increase calculation speed
 ROHR_injection = zeros(1,length(p));
 ROHR_injection_smooth = zeros(1,length(p));
 Q_numeric = zeros(1,length(p));
 Q_smooth = zeros(1,length(p));
 
 % Calculate the ROHR for the injection experiment, and the total fuel
 % energy released for both the numerically fitted pressure differential
 % and the smooth curve
 for l = 1:length(dp_injection)
    ROHR_injection(l) = 1/(kappa-1)*dp_injection(l)*V; %[J/s]
    ROHR_injection_smooth(l) = 1/(kappa-1)*dp_smooth(l)*V; %[J/s]
    Q_numeric(l) = h * trapz(ROHR_injection(1:l));
    Q_smooth(l) = h * trapz(ROHR_injection_smooth(1:l));
 end
 
 % Numerically fitted
 
 % Find the maximum value
 Q_numeric_100 = max(Q_numeric);

 
 % Set values for three points of mass of fuel burned
 Q1 = Q_numeric_100*Global.MFB1;
 Q2 = Q_numeric_100*Global.MFB2;
 Q3 = Q_numeric_100*Global.MFB3;
 
 % Find the index where the set mass of fuel is burned
 ind_1 = find(Q_numeric/Q_numeric_100>=Global.MFB1,1,'first');
 ind_2 = find(Q_numeric/Q_numeric_100>=Global.MFB2,1,'first');
 ind_3 = find(Q_numeric/Q_numeric_100>=Global.MFB3,1,'first');
 
 % Use linear interpolation to find a better estimate of the time
 if ind_1>=1
 
 Global.MFB_time_1 = (time_injection(ind_1-1) + (Q1-Q_numeric(ind_1-1))...
     * ((time_injection(ind_1)-time_injection(ind_1-1))...
     /(Q_numeric(ind_1)-Q_numeric(ind_1-1))))*1000;
 
  Global.MFB_time_2 = (time_injection(ind_2-1) + (Q2-Q_numeric(ind_2-1))...
     * ((time_injection(ind_2)-time_injection(ind_2-1))...
     /(Q_numeric(ind_2)-Q_numeric(ind_2-1))))*1000;

  Global.MFB_time_3 = (time_injection(ind_3-1) + (Q3-Q_numeric(ind_3-1))...
     * ((time_injection(ind_3)-time_injection(ind_3-1))...
     /(Q_numeric(ind_3)-Q_numeric(ind_3-1))))*1000;
 else
     % If the calculation fails, set all values to zero
     Global.MFB_time_1 = 0;
     Global.MFB_time_2 = 0;
     Global.MFB_time_3 = 0;
 end
 
 % Smooth curve
 
 % Find the maximum value
  Q_smooth_100 = max(Q_smooth);
 
 % Set values for three points of mass of fuel burned
 Q1_smooth = Q_smooth_100*Global.MFB1;
 Q2_smooth = Q_smooth_100*Global.MFB2;
 Q3_smooth = Q_smooth_100*Global.MFB3;
 
 % Find the index where the set mass of fuel is burned
 ind_1_s = find(Q_smooth/Q_smooth_100>=Global.MFB1,1,'first');
 ind_2_s = find(Q_smooth/Q_smooth_100>=Global.MFB2,1,'first');
 ind_3_s = find(Q_smooth/Q_smooth_100>=Global.MFB3,1,'first');
 
 % Use linear interpolation to find a better estimate of the time
 if ind_1_s>=1
     Global.MFB_time_1_smooth = (time_injection(ind_1_s-1)...
         + (Q1_smooth-Q_smooth(ind_1_s-1))...
     * ((time_injection(ind_1_s)-time_injection(ind_1_s-1))...
     /(Q_smooth(ind_1_s)-Q_smooth(ind_1_s-1))))*1000;

     Global.MFB_time_2_smooth = (time_injection(ind_2_s-1)...
         + (Q2_smooth-Q_smooth(ind_2_s-1))...
     * ((time_injection(ind_2_s)-time_injection(ind_2_s-1))...
     /(Q_smooth(ind_2_s)-Q_smooth(ind_2_s-1))))*1000;
 
    Global.MFB_time_3_smooth = (time_injection(ind_3_s-1)...
        + (Q3_smooth-Q_smooth(ind_3_s-1))...
     * ((time_injection(ind_3_s)-time_injection(ind_3_s-1))...
     /(Q_smooth(ind_3_s)-Q_smooth(ind_3_s-1))))*1000;
 else
     % If the calculation fails, set all values to zero
     Global.MFB_time_1_smooth = 0;
     Global.MFB_time_2_smooth = 0;
     Global.MFB_time_3_smooth = 0;
 end

% Set global parameters to display results in the GUI
Global.time_injection = time - Global.time(Global.injection_start);
Global.ROHR_injection_numeric = ROHR_injection;
Global.ROHR_injection_smooth = ROHR_injection_smooth;
Global.ROHR_pre_combustion = ROHR_pre_combustion;
Global.ROHR_pre_combustion_numeric = ROHR_pre_combustion_numeric;
Global.Q_pre_combustion = Q_pre_fit;
Global.Q_injection = trapz(time,ROHR_injection_smooth);
end

