function [ Global ] = TWO_ZONES( Global )
%TWO_ZONES Function for solving the two-sone model in the pre-combustion

% Time in pre-combustion phase
time = Global.time(1:Global.combustion_end+1); % [s]
% Pressure in pre-combustion phase
p = Global.p(1:Global.combustion_end+1); % [Pa]
% Volume of combustion rig
V = Global.V; % [m^3]
% Mass in rig 
mrig = Global.mrig; % [kg]
% Initial temperature in rig when gas combustion starts
T0 = Global.T0; % [K]
% Initial part of total mass and volume in zone 2
initial_part_zone2 = 0.03; % [-]
% Inital volume of zone 1
V1_0 = V; % [m^3]
% Counter variable for number of runs
s = Global.s; % [-]
% Temperature at beginning of cool down phase
T_cooldown = Global.T_cooldown; % [K]

% Make curve fit for making a smooth differential

% Make a fit for the pressure curve using the General model Fourier8:
%  f(time) =  a0 + a1*cos(w.*time) + b1*sin(w.*time) + a2*cos(2*w.*time)...
%         + b2*sin(2*w.*time) + a3*cos(3*w.*time) + b3*sin(3*w.*time)...
%         + a4*cos(4*w.*time) + b4*sin(4*w.*time) + a5*cos(5*w.*time)...
%         + b5*sin(5*w.*time) + a6*cos(6*w.*time) + b6*sin(6*w.*time)...
%         + a7*cos(7*w.*time) + b7*sin(7*w.*time) + a8*cos(8*w.*time)...
%         + b8*sin(8*w.*time)      

p_fit = fit(time,p','fourier8');

a0 = p_fit.a0;
a1 = p_fit.a1;
a2 = p_fit.a2;
a3 = p_fit.a3;
a4 = p_fit.a4;
a5 = p_fit.a5;
a6 = p_fit.a6;
a7 = p_fit.a7;
a8 = p_fit.a8;
b1 = p_fit.b1;
b2 = p_fit.b2;
b3 = p_fit.b3;
b4 = p_fit.b4;
b5 = p_fit.b5;
b6 = p_fit.b6;
b7 = p_fit.b7;
b8 = p_fit.b8;
w = p_fit.w;

% Calculate differential of pressure from fitted function
dp_fit = w*(-a1*sin(w.*time) - 2*a2*sin(2*w.*time) - 3*a3*sin(3*w.*time)...
    - 4*a4*sin(4*w.*time) - 5*a5*sin(5*w.*time) - 6*a6*sin(6*w.*time)...
    - 7*a7*sin(7*w.*time) - 8*a8*sin(8*w.*time)...
    + b1*cos(w.*time) + 2*b2*cos(2*w.*time) + 3*b3*cos(3*w.*time)...
    + 4*b4*cos(4*w.*time) + 5*b5*cos(5*w.*time) + 6*b6*cos(6*w.*time)...
    + 7*b7*cos(7*w.*time) + 8*b8*cos(8*w.*time));

% Calculate pressure from fitted function
p_fit_calc = a0 + a1*cos(w.*time) + b1*sin(w.*time) + a2*cos(2*w.*time)...
    + b2*sin(2*w.*time)+ a3*cos(3*w.*time) + b3*sin(3*w.*time)...
    + a4*cos(4*w.*time) + b4*sin(4*w.*time) + a5*cos(5*w.*time)...
    + b5*sin(5*w.*time) + a6*cos(6*w.*time) + b6*sin(6*w.*time)...
    + a7*cos(7*w.*time) + b7*sin(7*w.*time) + a8*cos(8*w.*time)...
    + b8*sin(8*w.*time);

% Initial conditions where x0(1) = m12, x0(2) = T1, x0(3) = V1, x0(4) = T2
x0 = [0 T0 V1_0 T0];

% Set timespan for the solving
timespan = [0 time(Global.combustion_end)];
% Set integration tolerances
options=odeset('RelTol',1e-6,'AbsTol',1e-6*ones(1,4));

% Solve the differential equations
[T,X] = ode15s(@ODEFUN,timespan,x0,options,...
    Global, p_fit_calc, dp_fit, initial_part_zone2);

% Finding resulting temperature in rig after pre-combustion
T1 = X(end,2);
T2 = X(end,4);
m2 = X(end,1);
m1 = mrig-m2;

% Check if temperature is above the minimum limit by coefficients in NASA
% GLENN DATABASE
% The resulting value may be to low when the solver fails early and the
% value of T2 drop
if T2>= 200
% Set up composition of each zone
[ zone1, zone2 ] = ZONES_DATA( Global );

% Calculate entalphy in zone 1
[ ~, ~, ~, h ] = ZONES_THERMO_PROPERTIES( T1, Global, zone1 );
h1 = h.zone;  % [J/kg] 

% Calculate entalphy in zone 2
[ ~, ~, ~, h ] = ZONES_THERMO_PROPERTIES( T2, Global, zone2 );
h2 = h.zone; % % [J/kg]

% Calculate the entalphy of the CR after pre-combustion,
% both zones completely mixed, based on resulting temperature in zone 2
[ h, temp ] = ENTALPHY(T2, Global);

% Solve the equation: m1*h1+m2*h2 = (m1+m2)*h for h12
h12 = (m1*h1+m2*h2)/(m1+m2); % [kJ/kg]

% Find the resulting temperature
ind = find(h12-h<10,1,'first'); 
T12 = temp(ind); % [K]

% Calculate the resulting difference
Global.T_diff(s) = T12 - T_cooldown; % [K]

% Resulting combustion efficiency
Global.eta_comb(s+1) = max(X(:,1))/mrig;

else
    Global.eta_comb(s+1) = Global.eta_comb(s)-0.001;
    Global.T_diff(s) = 0;
end

% Set final variables to display them in the GUI
Global.m12 = X(:,1); % [kg]
Global.T1 = X(:,2); % [T1]
Global.V1 = X(:,3); % [V1]
Global.T2 = X(:,4); % [T2]
Global.time_two_zones = T; % [s]
end

