function [ Cp, Cv, kappa, h, u ] = ZONES_THERMO_PROPERTIES( ...
    temp, Global, zone )
%ZONES_THERMO_PROPERTIES Calculates the termodynamic properties of the 
%combustion gases for both zone 1 and zone 2

% Set matrixes for increased calculation speed
CpR_CO = zeros(1,length(temp));
CpR_CO2 = zeros(1,length(temp));
CpR_H2 = zeros(1,length(temp));
CpR_N2 = zeros(1,length(temp));
CpR_O2 = zeros(1,length(temp));
CpR_H2O = zeros(1,length(temp));

h.CO = zeros(1,length(temp));
h.CO2 = zeros(1,length(temp));
h.H2 = zeros(1,length(temp));
h.N2 = zeros(1,length(temp));
h.O2 = zeros(1,length(temp));
h.H2O = zeros(1,length(temp));

u.CO = zeros(1,length(temp));
u.CO2 = zeros(1,length(temp));
u.H2 = zeros(1,length(temp));
u.N2 = zeros(1,length(temp));
u.O2 = zeros(1,length(temp));
u.H2O = zeros(1,length(temp));

% Defines the gas constants for use in this function
RCO = Global.RCO; % [J/kgK]
RCO2 = Global.RCO2; % [J/kgK]
RH2 = Global.RH2; % [J/kgK]
RN2 = Global.RN2; % [J/kgK]
RO2 = Global.RO2; % [J/kgK]
RH2O = Global.RH2O; % [J/kgK]

% Calculates Cp^0(T)/R and H^0(T)/RT using NASA GLENN DATABASE polynom

for i = 1:length(temp)
    
    % Import coefficents for the calculations
    [CO, CO2, H2, N2, O2, H2O] = COEFFICIENTS(temp(i));
    
    CpR_CO(i) = (CO(1)*temp(i)^-2 + CO(2)*temp(i)^-1 + ...
        CO(3) + CO(4)*temp(i) + CO(5)*temp(i)^2 + ...
        CO(6)*temp(i)^3 + CO(7)*temp(i)^4);
    
    CpR_CO2(i) = (CO2(1)*temp(i)^-2 + CO2(2)*temp(i)^-1 + ...
        CO2(3) + CO2(4)*temp(i) + CO2(5)*temp(i)^2 + ...
        CO2(6)*temp(i)^3 + CO2(7)*temp(i)^4);
    
    CpR_H2(i) = (H2(1)*temp(i)^-2 + H2(2)*temp(i)^-1 + ...
        H2(3) + H2(4)*temp(i) + H2(5)*temp(i)^2 + ...
        H2(6)*temp(i)^3 + H2(7)*temp(i)^4);
    
    CpR_N2(i) = (N2(1) * temp(i)^-2 + N2(2) * temp(i)^-1 + ...
        N2(3) + N2(4)*temp(i) + N2(5)*temp(i)^2 + ...
        N2(6)*temp(i)^3 + N2(7)*temp(i)^4);
    
    CpR_O2(i) = (O2(1) * temp(i)^-2 + O2(2) * temp(i)^-1 + ...
        O2(3) + O2(4)*temp(i) + O2(5)*temp(i)^2 + ...
        O2(6)*temp(i)^3 + O2(7)*temp(i)^4);
    
    CpR_H2O(i) = (H2O(1)*temp(i)^-2 + H2O(2)*temp(i)^-1 + ...
        H2O(3) + H2O(4)*temp(i) + H2O(5)*temp(i)^2 + ...
        H2O(6)*temp(i)^3 + H2O(7)*temp(i)^4);
    
    % Calculates h(T) [J/kg] with h(T) = [H^0(T)/RT]*RT for each gas
    h.CO(i) = (-CO(1)*(temp(i)^-2) + CO(2)*(log(temp(i))/temp(i)) ...
        + CO(3) + CO(4)*temp(i)/2 + CO(5)*(temp(i)^2)/3 ...
        + CO(6)*(temp(i)^3)/4 + CO(7)*(temp(i)^4)/5 ...
        + CO(8)/temp(i)) * RCO*temp(i);

    h.CO2(i) = (-CO2(1)*temp(i)^-2 + CO2(2)*(log(temp(i))/temp(i)) + ...
        CO2(3) + CO2(4)*temp(i)/2 + CO2(5)*((temp(i)^2)/3) + ...
        CO2(6)*((temp(i)^3)/4) + CO2(7)*((temp(i)^4)/5) + ...
        CO2(8)/temp(i)) * RCO2*temp(i);
   
    h.H2(i) = (-H2(1)*temp(i)^-2 + H2(2)*(log(temp(i))/temp(i)) + ...
        H2(3) + H2(4)*temp(i)/2 + H2(5)*((temp(i)^2)/3) + ...
        H2(6)*((temp(i)^3)/4) + H2(7)*((temp(i)^4)/5) + ...
        H2(8)/temp(i)) * RH2*temp(i);
    
    h.N2(i) = (-N2(1)*temp(i)^-2 + N2(2)*(log(temp(i))/temp(i)) + ...
        N2(3) + N2(4)*temp(i)/2 + N2(5)*((temp(i)^2)/3) + ...
        N2(6)*((temp(i)^3)/4) + N2(7)*((temp(i)^4)/5) + ...
        N2(8)/temp(i)) * RN2*temp(i);
    
    h.O2(i) = (-O2(1)*temp(i)^-2 + O2(2)*(log(temp(i))/temp(i)) + ...
        O2(3) + O2(4)*temp(i)/2 + O2(5)*((temp(i)^2)/3) + ...
        O2(6)*((temp(i)^3)/4) + O2(7)*((temp(i)^4)/5) + ...
        O2(8)/temp(i)) * RO2*temp(i);
    
    h.H2O(i) = (-H2O(1)*temp(i)^-2 + H2O(2)*(log(temp(i))/temp(i)) + ...
        H2O(3) + H2O(4)*temp(i)/2 + H2O(5)*((temp(i)^2)/3) + ...
        H2O(6)*((temp(i)^3)/4) + H2O(7)*((temp(i)^4)/5) + ...
        H2O(8)/temp(i)) * RH2O*temp(i);
    
    % Calculates h(T) for the specific zone in the two zone model
    h.zone = h.CO*zone.xCO + h.CO2*zone.xCO2 + h.H2*zone.xH2 + ...
        h.N2*zone.xN2 + h.O2*zone.xO2 + h.H2O*zone.xH2O;
    
    % Calculates u(T) [J/kg] with u(T) = h(T) - RT for each gas
    u.CO(i) = h.CO(i) - RCO*temp(i);
    u.CO2(i) = h.CO2(i) - RCO2*temp(i);
    u.H2(i) = h.H2(i) - RH2*temp(i);
    u.N2(i) = h.N2(i) - RN2*temp(i);
    u.O2(i) = h.O2(i) - RO2*temp(i);
    u.H2O(i) = h.H2O(i) - RH2O*temp(i);

    % Calculates u(T) for the specific zone in the two zone model
    u.zone = u.CO*zone.xCO + u.CO2*zone.xCO2 + u.H2*zone.xH2 + ...
        u.N2*zone.xN2 + u.O2*zone.xO2 + u.H2O*zone.xH2O;

end

% Calculates Cp(T) [J/kgK] with Cp(T) = [Cp^0(T)/R]*R for each gas
    Cp.CO = CpR_CO .* RCO;
    Cp.CO2 = CpR_CO2 .* RCO2;
    Cp.H2 = CpR_H2 .* RH2;
    Cp.N2 = CpR_N2 .* RN2;
    Cp.O2 = CpR_O2 .* RO2;
    Cp.H2O = CpR_H2O .* RH2O;

% Calculates Cv(T) [J/kgK] with Cv(T) = Cp(T) - R for each gas
    Cv.CO = Cp.CO - RCO;
    Cv.CO2 = Cp.CO2 - RCO2;
    Cv.H2 = Cp.H2 - RH2;
    Cv.N2 = Cp.N2 - RN2;
    Cv.O2 = Cp.O2 - RO2;
    Cv.H2O = Cp.H2O - RH2O;
    
% Calculates Cv(T) for the specific zone in the two zone model
    Cv.zone = Cv.CO*zone.xCO + Cv.CO2*zone.xCO2 + Cv.H2*zone.xH2 + ...
        Cv.N2*zone.xN2 + Cv.O2*zone.xO2 + Cv.H2O*zone.xH2O;

% Calculates kappa [-] with kappa = Cp/Cv for each gas
    kappa.CO = Cp.CO./Cv.CO;
    kappa.CO2 = Cp.CO2./Cv.CO2;
    kappa.H2 = Cp.H2./Cv.H2;
    kappa.N2 = Cp.N2./Cv.N2;
    kappa.O2 = Cp.O2./Cv.O2;
    kappa.H2O = Cp.H2O./Cv.H2O;